factorize_supernodal_numeric_intranode_lblt

Function factorize_supernodal_numeric_intranode_lblt 

pub fn factorize_supernodal_numeric_intranode_lblt<I: Index, T: ComplexField>(
    L_values: &mut [T],
    subdiag: &mut [T],
    perm_forward: &mut [I],
    perm_inverse: &mut [I],
    A_lower: SparseColMatRef<'_, I, T>,
    symbolic: &SymbolicSupernodalCholesky<I>,
    par: Par,
    stack: &mut MemStack,
    params: Spec<LbltParams, T>,
) -> LbltInfo
computes the numeric values of the cholesky $LBL^\top$ factors of the matrix $A$ with intranodal pivoting, and stores them in l_values

note

only the lower (not upper, unlike the other functions) triangular part of $A$ is accessed

panics

the symbolic structure must be computed by calling factorize_supernodal_symbolic_cholesky on a matrix with the same symbolic structure otherwise, the behavior is unspecified and panics may occur