factorize_supernodal_numeric_ldlt

Function factorize_supernodal_numeric_ldlt 

pub fn factorize_supernodal_numeric_ldlt<I: Index, T: ComplexField>(
    L_values: &mut [T],
    A_lower: SparseColMatRef<'_, I, T>,
    regularization: LdltRegularization<'_, T::Real>,
    symbolic: &SymbolicSupernodalCholesky<I>,
    par: Par,
    stack: &mut MemStack,
    params: Spec<LdltParams, T>,
) -> Result<LdltInfo, LdltError>
computes the numeric values of the cholesky $LDL^H$ factors of the matrix $A$, and stores them in l_values

note

only the lower (not upper, unlike the other functions) triangular part of $A$ is accessed

panics

the symbolic structure must be computed by calling factorize_supernodal_symbolic_cholesky on a matrix with the same symbolic structure otherwise, the behavior is unspecified and panics may occur