pub fn factorize_supernodal_symbolic_cholesky<I: Index>(
A: SymbolicSparseColMatRef<'_, I>,
etree: EliminationTreeRef<'_, I>,
col_counts: &[I],
stack: &mut MemStack,
params: SymbolicSupernodalParams<'_>,
) -> Result<SymbolicSupernodalCholesky<I>, FaerError>Expand description
computes the supernodal symbolic structure of the cholesky factor of the matrix $A$
note
only the upper triangular part of $A$ is analyzed
panics
the elimination tree and column counts must be computed by calling
simplicial::prefactorize_symbolic_cholesky with the same matrix. otherwise, the behavior
is unspecified and panics may occur