pub fn factorize_supernodal_symbolic_cholesky_scratch<I: Index>( n: usize, ) -> StackReq
returns the size and alignment of the workspace required to compute the symbolic supernodal factorization of a matrix of size n
n