pub struct SymbolicSupernodalCholesky<I> { /* private fields */ }Expand description
cholesky factor structure containing its symbolic structure
Implementations
Sourceimpl<I: Index> SymbolicSupernodalCholesky<I>
impl<I: Index> SymbolicSupernodalCholesky<I>
Sourcepub fn n_supernodes(&self) -> usize
pub fn n_supernodes(&self) -> usize
returns the number of supernodes in the cholesky factor
Sourcepub fn len_val(&self) -> usize
pub fn len_val(&self) -> usize
returns the length of the slice that can be used to contain the numerical values of the cholesky factor
Sourcepub fn supernode_begin(&self) -> &[I]
pub fn supernode_begin(&self) -> &[I]
returns a slice of length self.n_supernodes() containing the beginning index of each
supernode
Sourcepub fn supernode_end(&self) -> &[I]
pub fn supernode_end(&self) -> &[I]
returns a slice of length self.n_supernodes() containing the past-the-end index of
each
Sourcepub fn col_ptr_for_row_idx(&self) -> &[I]
pub fn col_ptr_for_row_idx(&self) -> &[I]
returns the column pointers for row indices of each supernode
Sourcepub fn col_ptr_for_val(&self) -> &[I]
pub fn col_ptr_for_val(&self) -> &[I]
returns the column pointers for numerical values of each supernode
Sourcepub fn row_idx(&self) -> &[I]
pub fn row_idx(&self) -> &[I]
returns the row indices of the cholesky factor
note
note that the row indices of each supernode do not contain those of the block diagonal part
Sourcepub fn supernode(&self, s: usize) -> SymbolicSupernodeRef<'_, I>
pub fn supernode(&self, s: usize) -> SymbolicSupernodeRef<'_, I>
returns the symbolic structure of the s’th supernode
Sourcepub fn solve_in_place_scratch<T: ComplexField>(
&self,
rhs_ncols: usize,
par: Par,
) -> StackReq
pub fn solve_in_place_scratch<T: ComplexField>( &self, rhs_ncols: usize, par: Par, ) -> StackReq
returns the size and alignment of the workspace required to solve the system $A x = rhs$